`factor.scores` <-
function (object, ...) {
    UseMethod("factor.scores")
}

